Module git

Module git 

Structs

GitEntry
Extended entry with git status

Enums

GitStatus
Git file status

Functions

enrich_with_git_status
Enrich entries with git status information
get_changed_since
Get files changed since a specific ref (branch/commit/tag)
get_git_status
Get git status for all files in a repository
is_git_repo
Check if a path is within a git repository