Fuzzy search for projects
Provides fuzzy matching on project names and paths, combined with frecency scoring for intelligent ranking.
Structs
- Project
Searcher - Project fuzzy searcher with integrated frecency ranking
Fuzzy search for projects
Provides fuzzy matching on project names and paths, combined with frecency scoring for intelligent ranking.