Structs
- GitEntry
- Extended entry with git status
Enums
- GitStatus
- Git file status
Functions
- enrich_
with_ git_ status - Enrich entries with git status information
- get_
changed_ since - Get files changed since a specific ref (branch/commit/tag)
- get_
git_ status - Get git status for all files in a repository
- is_
git_ repo - Check if a path is within a git repository